@@ -39,17 +39,17 @@ class kpMacroCommand : public kpNamedCommand
 {
 public:
     kpMacroCommand (const QString &name, kpCommandEnvironment *environ);
-    virtual ~kpMacroCommand ();
+    ~kpMacroCommand () override;
 
 
     //
     // kpCommand Interface
     //
 
-    SizeType size () const Q_DECL_OVERRIDE;
+    SizeType size () const override;
 
-    void execute () Q_DECL_OVERRIDE;
-    void unexecute () Q_DECL_OVERRIDE;
+    void execute () override;
+    void unexecute () override;
 
 
     //
